@@ -3,6 +3,7 @@ knitr::opts_chunk$set(fig.width=4, fig.height=3.5)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 library("lessR")
+d <- Read("Employee")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 getColors("hues")
@@ -14,22 +15,32 @@ getColors(in_order=TRUE)
 getColors(n=36, shape="wheel", border="off")
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors(c=90, l=45)
+BarChart(Dept, fill=getColors(c=90, l=45))
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors("blues", labels=FALSE)
+#showPalettes()
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors("browns", c=c(20,90), l=60)
+BarChart(Dept, fill=getColors("blues"))
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors("rusts", "blues", n=7)
+BarChart(Dept, fill=getColors("blues", c=60, l=c(30,80)))
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors("rusts", "blues", n=7, c=45)
+BarChart(Dept, fill=getColors("browns", c=c(20,90), l=60))
+
+## ---- fig.width=6-----------------------------------------------------------------------------------------------------
+d <- Read("StockPrice", quiet=TRUE)
+Plot(date, Price, by=Company, trans=0.4, stack=TRUE, area_fill="reds")
+d <- Read("Employee", quiet=TRUE)
+
+## ---------------------------------------------------------------------------------------------------------------------
+BarChart(Dept, fill=getColors("rusts", "blues"))
+
+## ---------------------------------------------------------------------------------------------------------------------
+BarChart(Dept, fill=getColors("rusts", "blues", c=45))
 
 ## ---------------------------------------------------------------------------------------------------------------------
-d <- Read("Employee")
 BarChart(Dept, fill=getColors(c=90, l=45))
 
 ## ---------------------------------------------------------------------------------------------------------------------
