@@ -1,9 +1,8 @@
 ## ---- include=FALSE---------------------------------------------------------------------------------------------------
-knitr::opts_chunk$set(fig.width=4, fig.height=3.5)
+knitr::opts_chunk$set(fig.width=4.5, fig.height=4)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 library("lessR")
-style()
 
 ## ----read-------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
@@ -17,21 +16,44 @@ Plot(Years, Salary, enhance=TRUE)
 ## ----sploess, fig.width=4.5-------------------------------------------------------------------------------------------
 Plot(Years, Salary, fit="loess", plot_errors=TRUE)
 
-## ----size, fig.width=4.5----------------------------------------------------------------------------------------------
-Plot(Years, Salary, size=Pre)
-
-## ----by, fig.width=5--------------------------------------------------------------------------------------------------
-Plot(Years, Salary, by=Gender)
-
-## ---- , fig.width=4.5, fig.height=4-----------------------------------------------------------------------------------
-Plot(Years, Salary, by1=Gender)
-
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Dept, Gender)
 
+## ---------------------------------------------------------------------------------------------------------------------
+Plot(Gender, Salary)
+
+## ----size, fig.width=4.5----------------------------------------------------------------------------------------------
+Plot(Years, Salary, size=Pre)
+
+## ----by, fig.width=6--------------------------------------------------------------------------------------------------
+Plot(Years, Salary, by=Gender)
+
+## ---- fig.width=4.5, fig.height=4-------------------------------------------------------------------------------------
+Plot(Years, Salary, by1=Gender)
+
+## ---- fig.width=6, fig.height=5---------------------------------------------------------------------------------------
+Plot(Years, Salary, by1=Dept, by2=Gender, by=Plan, fit="lm")
+
+## ----three, fig.width=5, fig.height=4---------------------------------------------------------------------------------
+Plot(c(Pre, Post), Salary, fit="lm", fit_se=0)
+
+## ----spmat, , fig.width=5, fig.height=5-------------------------------------------------------------------------------
+Plot(c(Salary, Years, Pre, Post), fit=TRUE)
+
+## ---------------------------------------------------------------------------------------------------------------------
+x <- rnorm(5000)
+y <- rnorm(5000)
+Plot(x, y)
+
+## ---------------------------------------------------------------------------------------------------------------------
+Plot(x, y, smooth=FALSE, trans=.97, theme="slatered")
+
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Salary)
 
+## ---------------------------------------------------------------------------------------------------------------------
+Plot(Salary, run=TRUE)
+
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Dept)
 
@@ -54,19 +76,38 @@ Plot(date, Price, rows=(Company=="Apple"))
 ## ---- fig.width=5-----------------------------------------------------------------------------------------------------
 Plot(date, Price, by=Company)
 
+## ---- fig.width=5-----------------------------------------------------------------------------------------------------
+Plot(date, Price, by=Company, stack=TRUE)
+
 ## ---- fig.width=4.5---------------------------------------------------------------------------------------------------
 Plot(date, Price, by1=Company)
 
 ## ---- fig.width=4.5---------------------------------------------------------------------------------------------------
-style(sub_theme="black", trans=.55,
-      window_fill="gray10", grid_color="gray25")
-Plot(date, Price, by1=Company, n_col=1,  fill="darkred", color="red")
+style(sub_theme="black", window_fill="gray10")
+Plot(date, Price, by1=Company, n_col=1,  fill="darkred", color="red", trans=.55)
+style()
+
+## ---- fig.wdith=6.5---------------------------------------------------------------------------------------------------
+Plot(date, Price, by=Company, trans=0.4, stack=TRUE, area_fill="emeralds")
+
+## ---------------------------------------------------------------------------------------------------------------------
+dw <- reshape(d, direction = "wide",
+        idvar = "date", timevar = "Company",
+        varying = list(c("Apple", "IBM", "Intel")))
+head(dw)
+
+## ---- fig.wdith=6.5---------------------------------------------------------------------------------------------------
+Plot(date, c(Intel, Apple, IBM), area_fill="blues", stack=TRUE, trans=.4, data=dw)
+
+## ---- fig.wdith=5-----------------------------------------------------------------------------------------------------
+a1.ts <- ts(dw$Apple, frequency=12, start=c(1980, 12))
+Plot(a1.ts)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 style()
 
 ## ---------------------------------------------------------------------------------------------------------------------
-d <- Read("Employee")
+d <- Read("Employee", quiet=TRUE)
 
 ## ----fig.width=4.5----------------------------------------------------------------------------------------------------
 Plot(Years, Salary, add=c("Hi", "Bye", "Wow"), x1=c(12, 16, 18),
